@@ -35,12 +35,12 @@
 
 // Set the QDBUS_DEBUG env variable for debugging Qt DBUS calls.
 
-Mixer_Backend* MPRIS2_getMixer(Mixer *mixer, int device )
+MixerBackend* MPRIS2_getMixer(Mixer *mixer, int device )
 {
 	return new Mixer_MPRIS2(mixer, device );
 }
 
-Mixer_MPRIS2::Mixer_MPRIS2(Mixer *mixer, int device) : Mixer_Backend(mixer, device )
+Mixer_MPRIS2::Mixer_MPRIS2(Mixer *mixer, int device) : MixerBackend(mixer, device )
 {
 }
 
@@ -50,7 +50,7 @@ int Mixer_MPRIS2::open()
 	if ( m_devnum !=  0 )
 		return Mixer::ERR_OPEN;
 
-	registerCard(i18n("Playback Streams"));
+	registerCard(i18n("Application Streams"));
 	_id = "Playback Streams";
 	_mixer->setDynamic();
 	return addAllRunningPlayersAndInitHotplug();
@@ -590,17 +590,17 @@ void Mixer_MPRIS2::announceControlListAsync(QString /*streamId*/)
 
 void Mixer_MPRIS2::announceControlList()
 {
-    ControlManager::instance().announce(_mixer->id(), ControlManager::ControlList, getDriverName());
+    ControlManager::instance()->announce(_mixer->id(), ControlManager::ControlList, getDriverName());
 }
 
 void Mixer_MPRIS2::announceGUI()
 {
-    ControlManager::instance().announce(_mixer->id(), ControlManager::GUI, getDriverName());
+    ControlManager::instance()->announce(_mixer->id(), ControlManager::GUI, getDriverName());
 }
 
 void Mixer_MPRIS2::announceVolume()
 {
-    ControlManager::instance().announce(_mixer->id(), ControlManager::Volume, getDriverName());
+    ControlManager::instance()->announce(_mixer->id(), ControlManager::Volume, getDriverName());
 }
 
 // -----------------------------------------------------------------------------------------------------------
@@ -724,13 +724,10 @@ MPrisControl::~MPrisControl()
 	delete playerIfc;
 }
 
+
+const char *MPRIS2_driverName = "MPRIS2";
+
 QString Mixer_MPRIS2::getDriverName()
 {
-	return "MPRIS2";
+	return (MPRIS2_driverName);
 }
-
-QString MPRIS2_getDriverName()
-{
-	return "MPRIS2";
-}
-
